@@ -91,12 +91,10 @@ impl<'a> Builder<'a> {
 	/// ### Errors
 	/// - Returns an error if a `Leaf` with the specified `ID` exists.
 	pub fn add_leaf(&mut self, leaf: Leaf<'a>) -> InternalResult<()> {
-		{
-			// Make sure no two leaves are written with the same ID
-			if !self.id_set.insert(leaf.id.clone()) {
-				return Err(InternalError::LeafAppendError(leaf.id));
-			};
-		}
+		// Make sure no two leaves are written with the same ID
+		if !self.id_set.insert(leaf.id.clone()) {
+			return Err(InternalError::LeafAppendError(leaf.id));
+		};
 
 		self.leafs.push(leaf);
 		Ok(())
@@ -119,7 +117,6 @@ impl<'a> Builder<'a> {
 
 	/// This iterates over all `Leaf`s in the processing queue, parses them and writes the bytes out into a the target.
 	/// Configure the custom *`MAGIC`*, Header flags and a `Keypair` using the `BuilderConfig` struct.
-	/// If a valid `Keypair` is provided, as `Some(keypair)`, then the data can be signed and some signatures will be embedded into the write target.
 	/// ### Errors
 	/// - Underlying `io` errors
 	/// - If the optional compression or compression stages fails
@@ -129,8 +126,24 @@ impl<'a> Builder<'a> {
 	) -> InternalResult<usize> {
 		// Keep track of how many bytes are written, and where bytes are being written
 		let mut size = 0usize;
-		let mut reg_offset = 0;
-		let mut leaf_offset = Header::BASE_SIZE;
+		let mut reg_buffer = Vec::new();
+
+		// Calculate the size of the registry and check for `Leaf`s that request for encryption
+		let mut leaf_offset = self
+			.leafs
+			.iter()
+			.map(|leaf| {
+				// The size of it's ID, the minimum size of an entry without a signature, and the size of a signature only if a signature is incorporated into the entry
+				leaf.id.len()
+					+ RegistryEntry::MIN_SIZE
+					+ (if config.keypair.is_some() {
+						crate::SIGNATURE_LENGTH
+					} else {
+						0
+					})
+			})
+			.reduce(|l1, l2| l1 + l2)
+			.unwrap_or(0) + Header::BASE_SIZE;
 
 		// Start at the very start of the file
 		target.seek(SeekFrom::Start(0))?;
@@ -153,34 +166,18 @@ impl<'a> Builder<'a> {
 
 		// Update how many bytes have been written
 		size += Header::BASE_SIZE;
-		reg_offset += Header::BASE_SIZE;
 
 		// Configure encryption
-		let mut use_encryption = false;
+		let use_encryption = self.leafs.iter().any(|leaf| leaf.encrypt);
 
-		// Calculate the size of the registry and check for `Leaf`s that request for encryption
-		for leaf in self.leafs.iter() {
-			if leaf.encrypt && !use_encryption {
-				if config.keypair.is_none() {
-					return Err(InternalError::NoKeypairError(format!("Leaf encryption error! Leaf: {} requested for encryption, yet no keypair was provided(None)", &leaf.id)));
-				};
-
-				use_encryption = true;
-			}
-
-			// The size of it's ID, the minimum size of an entry without a signature, and the size of a signature only if a signature is incorporated into the entry
-			leaf_offset += leaf.id.len()
-				+ RegistryEntry::MIN_SIZE
-				+ (if config.keypair.is_some() {
-					crate::SIGNATURE_LENGTH
-				} else {
-					0
-				});
-		}
+		if use_encryption && config.keypair.is_none() {
+			return Err(InternalError::NoKeypairError("Leaf encryption error! A leaf requested for encryption, yet no keypair was provided(None)".to_string()));
+		};
 
 		// Build encryptor
 		let encryptor = if use_encryption {
 			let keypair = &config.keypair;
+
 			Some(EDCryptor::new(
 				&keypair.as_ref().unwrap().public,
 				config.magic,
@@ -290,14 +287,15 @@ impl<'a> Builder<'a> {
 			entry_bytes.extend(leaf.id.as_bytes());
 
 			// Write to the registry
-			wtr.seek(SeekFrom::Start(reg_offset as u64))?;
-			wtr.write_all(&entry_bytes)?;
+			reg_buffer.write_all(&entry_bytes)?;
 
 			// Update offsets
-			reg_offset += entry_bytes.len();
 			size += entry_bytes.len();
 		}
 
+		wtr.seek(SeekFrom::Start(Header::BASE_SIZE as u64))?;
+		wtr.write_all(reg_buffer.as_slice())?;
+
 		Ok(size)
 	}
 }
